==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/da.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administrer Lysbord gallary parametre");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Administrer Galleri");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Height");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniaturebillede Width");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniaturebillede Height");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bevar Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Vis Titler");
define('MANAGE_GALLERY_DISABLE_SORT', "Deaktiver Sortér");
define('MANAGE_GALLERY_DELETE_IMAGE', "Slet billede");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Gem Sort Bestil");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik på &#39;Opdater&#39; for at udgive <br /> dine uploadede billeder.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle billeder er blevet skaleret og indstillinger er gemt.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Der opstod en fejl resizing billeder eller gemme indstillinger.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Dit billede (r) er blevet uploadet.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Der var en fejl ved upload dit billede (r).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Den fil, du forsøger at uploade er ikke et billede.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Den fil, du forsøger at uploade er for stor.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titlen er blevet gemt.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Er du sikker på at du vil slette billedet");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Billedet er blevet slettet.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Der opstod en fejl at slette billedet.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Lagring parametre og ændring af billedstørrelse, vent venligst ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Upload, vent venligst ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Sorteringsrækkefølgen er ikke blevet gemt. Ønsker du at gemme sorteringsrækkefølgen?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Billedet sorteringsrækkefølgen er blevet gemt.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Der var en fejl med at gemme billedet slags.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/da.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administrer Lysbord gallary parametre");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Administrer Galleri");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Height");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniaturebillede Width");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniaturebillede Height");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bevar Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Vis Titler");
define('MANAGE_GALLERY_DISABLE_SORT', "Deaktiver Sortér");
define('MANAGE_GALLERY_DELETE_IMAGE', "Slet billede");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Gem Sort Bestil");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik på &#39;Opdater&#39; for at udgive <br /> dine uploadede billeder.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle billeder er blevet skaleret og indstillinger er gemt.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Der opstod en fejl resizing billeder eller gemme indstillinger.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Dit billede (r) er blevet uploadet.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Der var en fejl ved upload dit billede (r).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Den fil, du forsøger at uploade er ikke et billede.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Den fil, du forsøger at uploade er for stor.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titlen er blevet gemt.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Er du sikker på at du vil slette billedet");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Billedet er blevet slettet.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Der opstod en fejl at slette billedet.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Lagring parametre og ændring af billedstørrelse, vent venligst ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Upload, vent venligst ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Sorteringsrækkefølgen er ikke blevet gemt. Ønsker du at gemme sorteringsrækkefølgen?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Billedet sorteringsrækkefølgen er blevet gemt.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Der var en fejl med at gemme billedet slags.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Filen, du prøver at uploade, er større end &#39;upload_max_filesize&#39; eller &#39;post_max_size&#39; PHP-indstillingerne. Kontakt din systemadministrator for at øge disse grænser.");
?>
